@@ -34,7 +34,7 @@ class Nickname(models.Model):
     derogatory = models.NullBooleanField(default=None) # eg 'Rat, Ass,Dickwad, Douche Bag
     familial = models.NullBooleanField(default=None) # eg Mom, Dad, Son, Cuz, Gramps
     physical = models.NullBooleanField(default=None) # eg Fatso, Red, Baldy
-    personality = models.NullBooleanFiel(default=None) # eg Grumpy, Crazy, Drunken, Brainy, Dopey
+    personality = models.NullBooleanField(default=None) # eg Grumpy, Crazy, Drunken, Brainy, Dopey
     surname = models.NullBooleanField(default=None) # use of persons last name
 
     class Meta:
